# YouRAG

Your tool for RAG on any source of knowledge.

## Install

`uv add yourag`

## How to use 

`
yourag init --knowledge https://youtube.com/... --name docker-video
yourag query --name docker-video --question "How do I install this?"
yourag delete --name myvideo
`
